Tetris Gate Example
===================

Build on top of `tetris_polynomial`, the following is added:

* `soft_one_hot_linspace`
* `e3nn.nn.Gate`

.. rubric:: code

.. literalinclude:: ../../examples/tetris_gate.py

Full code `here <https://github.com/e3nn/e3nn/blob/main/examples/tetris_gate.py>`_
